@@ -5,20 +5,31 @@ use content_analysis_job::ContentAnalysisJob;
 use std::io::Result;
 use zmq::Context;
 use zmq::{REQ, REP};
+use nNye_solana_communication_layer::ISolana;
+use std::rc::Rc;
 
+
+/// This trait provides and abstraction for notifications queue.
 pub trait INotificationsQueue {
+    /// Adds a content notification to the queue.
     fn add_notification(&self, notification: &ContentNotification) -> Result<()>;
+
+    /// Retrieves a notification from the queue.
     fn get_notification(&self) -> ContentNotification;
 }
 
-pub trait Constructor {
-    fn new(context: &Context, backend_endpoint: &String, frontend_endpoint: &String) -> Self;
-}
-
+/// This structure implements INotificationsQueue.
 pub struct NotificationsQueue {
+    /// A zmq context
     context: Context,
+
+    /// The endpoint of the queue's backend
     backend_endpoint: String,
+
+    /// The endpoint of the queue's frontend
     frontend_endpoint: String,
+
+    solana: Rc<dyn ISolana>
 }
 
 impl INotificationsQueue for NotificationsQueue {
@@ -44,16 +55,21 @@ impl INotificationsQueue for NotificationsQueue {
 
         let job_bytes = responder.recv_bytes(0).unwrap();
         let job = ContentAnalysisJob::from_bytes(&job_bytes);
-        job.to_business_entitiy()
+        job.to_business_entitiy(Rc::clone(&self.solana))
     }
 }
 
-impl Constructor for NotificationsQueue {
-    fn new(context: &Context, frontend_endpoint: &String, backend_endpoint: &String) -> NotificationsQueue {
+impl NotificationsQueue {
+    pub fn new(context: &Context, 
+           frontend_endpoint: &String, 
+           backend_endpoint: &String,
+           solana: Rc<dyn ISolana>) -> NotificationsQueue {
+
         NotificationsQueue { 
             context: context.clone(), 
             frontend_endpoint: frontend_endpoint.clone(), 
-            backend_endpoint: backend_endpoint.clone()
+            backend_endpoint: backend_endpoint.clone(),
+            solana: solana
         } 
     }
 }
